//function(width, height, texturesPath) {

// Create effect in temporary storage and get URL on it
var effectFile = new Blob([files['scripts/rain.js']], {type: 'text/javascript'});
var effectUrl = window.URL.createObjectURL(effectFile);

// Create PIXI renderer
var renderer = PIXI.autoDetectRenderer(width, height, {backgroundColor: 0x000000});

// This is a size the scene is intended to be.
var baseSize = [800, 600];

// Create NeutrinoParticles context and set base path to the textures
var neutrinoContext = new PIXINeutrinoContext(renderer);
neutrinoContext.texturesBasePath = texturesPath;

// Generate noise (necessary only if noise is used in effects)
var noiseGenerator = new neutrinoContext.neutrino.NoiseGenerator();
while (!noiseGenerator.step()) { // approx. 5,000 steps
    // you can use 'noiseGenerator.progress' to get generating progress from 0.0 to 1.0
}

var stage = new PIXI.Container();

// Create base container which will be adjusted to keep aspect ration of the scene
var base = new PIXI.Container();
stage.addChild(base);

// Add backgroup (I don't remeber why it is necessary, but it probably is)

let background = PIXI.Sprite.fromImage(texturesPath + 'rain.jpg')
base.addChild(background);

let effectStartPosition = [0, 0, 0];
let effectStartRotation = 0;

var testModel = new PIXINeutrinoEffectModel(neutrinoContext, effectUrl);
var testEffect = new PIXINeutrinoEffect(testModel, effectStartPosition, effectStartRotation);

// Set base parent for particles. They will live in space of that parent.
testEffect.baseParent = base;

base.addChild(testEffect);

if (testEffect.ready()) {
    animate();
} else {
    testEffect.once('ready', animate);
}

var lastUpdateTime = null;

function animate() {
    if (lastUpdateTime == null) {
      lastUpdateTime = Date.now();
    }

    var currentTime = Date.now();
    var elapsedTime = (currentTime - lastUpdateTime) / 1000;
    lastUpdateTime = currentTime;

    testEffect.update(elapsedTime > 1.0 ? 1.0 : elapsedTime);

    renderer.render(stage);

    requestAnimationFrame(animate);
}

// Resize function for the scene. (Usualy is kept unchanged)
function resized(width, height) {
	var baseRatio = baseSize[0] / baseSize[1];

    var w, h;
    if (width / height >= baseRatio) {
        w = height * baseRatio;
        h = height;
        base.position.x = (width - w) * 0.5;
        base.position.y = 0;
    } else {
        w = width;
        h = width / baseRatio;
        base.position.x = 0;
        base.position.y = (height - h) * 0.5;
    }
    base.scale.x = w / baseSize[0];
    base.scale.y = h / baseSize[1];
}
renderer.onresize = resized;
resized(width, height);

// Introducing interactiveness.

// Important! Return renderer in the end.
return renderer;

//}
